import OcStrategy from '../strategy/validateStrategy';

/**
 * 集合汇总-自定义校验
 *
 *
 */

const OcValidator = {
    /***
     * 校验大于等于${low}的正整数
     ** @function newPwdCheck
     * @param {String} value
     * @param {Array} strategyArr
     * @returns {Object}
     */
    newPwdCheck: (rule, value, callback) => {
        if (value) {
            callback(new Error(`xxx`));
        } else {
            callback();
        }
    },
    /**
   * 判断是否相等，例如密码是否相同校验
   * @param {*} data 需要被比较的值
   * @param {string} message 错误提示文案
   */
    checkEqual: function (data, message) {
        return (rule, value, callback) => {
            if (value) {
                value === data ? callback() : callback(new Error(message))
            } else {
                callback()
            }
        }
    },
    /**
  * 判断该值是否比传入的值大
  * @param {*} data 需要被比较的值
  * @param {string} message 错误提示文案
  */
    checkGreater: function (data, message) {
        return (rule, value, callback) => {
            if (value) {
                value > data ? callback() : callback(new Error(message))
            } else {
                callback()
            }
        }
    },
    /**
     * 判断该值是否比传入的值小
     * @param {*} data 需要被比较的值
     * @param {string} message 错误提示文案
     */
    checkLess: function (data, message) {
        return (rule, value, callback) => {
            if (value) {
                value < data ? callback() : callback(new Error(message))
            } else {
                callback()
            }
        }
    },
    /**
     * ${limit} 以内的正整数
     * @param {*} limit
     * @param {string} message 错误提示文案
     */
    numLimitCheck: function (limit, message) {
        const isNum = OcStrategy.posiNum;
        return (rule, value, callback) => {
            if (value) {
                isNum.test(value) && value <= limit ? callback() : callback(new Error(message))
            } else {
                callback()
            }
        }
    },
    /***
     * 校验正整数
     *
     */
    isParseInt: function isParseInt() {
        const isNum = OcStrategy.posiNum;
        return (rule, value, callback) => {
            if (!value) {
                callback();
            } else {
                isNum.test(value) ? callback() : callback(new Error('请输入整数'));
            }
        };
    },
};

export default OcValidator;
